==> esup-canal-stockage-4.0-RC-1.zip: CStockage-4.0-RC-1/source/org/esupportail/portal/channels/CStockage/exception/DataBaseException.java <==
/*
ESUP-portail is a french academic project developed under the GPL (General Public License) augmented according to the following :
A binary or source file developped by ESUP-portail can be used or compiled with products under Apache license.
The official english text of the GPL can be found here : http://www.gnu.org/licenses/gpl.html .
A non official french translation can be found here : http://www.linux-France.org/article/these/gpl.html .
The different kinds of licenses governing the products developed by the Apache foundation can be found here : http://www.apache.org/licenses .
It follows that you can as well as use download contents as well modify and redistribute them provided you respect the GPL terms.
Downloading and using such contents do not provide any guaranty.
Be sure that you have well understood the terms of the license before using the contents it covers.
The ESUP-portail distribution includes the following distributions :
    * UPortal :
      software developed by JA-SIG (Java Architecture - Special Interest Group)
      You can find the license page here : http://mis105.udel.edu/ja-sig/uportal/license.html
    * CAS :
      SSO solution developed by Yale University
      You can find the project page here : http://www.yale.edu/tp/auth
    * Cocoon :
      XML framework distributed by the Apache foundation under Apache license;
      Please find the full text here : http://cocoon.apache.org/2.1/license.html
    * Mod_dav:
      A DAV module for Apache web server
      You can find the project page here : http://www.webdav.org/mod_dav
    * IMP :
      webmail from Horde application framework
      You can find the project page here : http://www.horde.org
    * . To be completed
*/

package org.esupportail.portal.channels.CStockage.exception;

/**
 * Id: DataBaseException.java,v 1.0 13 janvier 2005<br/>
 * Copyright (c) 2005 Esup Portail (www.esup-portail.org)<br/>
 * Classes: DataBaseException<br/>
 * Original Author: Yohan Colmant<br/>
 * Called when there is an error in the database access<br/>
 */
public class DataBaseException extends ChannelException {
	
	
	/**
	 * Constructor
	 */
	public DataBaseException() {
		super(1049);		
	}
	
	/**
	 * Constructor 
	 * @param httpErrorCode the error code return by the webdav
	 */
	public DataBaseException(int httpErrorCode) {
		super(1049, httpErrorCode);		
	}
	
}

==> esup-canal-stockage-4.3-RC-1.zip: CStockage-4.3-RC-1/source/org/esupportail/portal/channels/CStockage/exception/DataBaseException.java <==
/*
ESUP-portail is a french academic project developed under the GPL (General Public License) augmented according to the following :
A binary or source file developped by ESUP-portail can be used or compiled with products under Apache license.
The official english text of the GPL can be found here : http://www.gnu.org/licenses/gpl.html .
A non official french translation can be found here : http://www.linux-France.org/article/these/gpl.html .
The different kinds of licenses governing the products developed by the Apache foundation can be found here : http://www.apache.org/licenses .
It follows that you can as well as use download contents as well modify and redistribute them provided you respect the GPL terms.
Downloading and using such contents do not provide any guaranty.
Be sure that you have well understood the terms of the license before using the contents it covers.
The ESUP-portail distribution includes the following distributions :
    * UPortal :
      software developed by JA-SIG (Java Architecture - Special Interest Group)
      You can find the license page here : http://mis105.udel.edu/ja-sig/uportal/license.html
    * CAS :
      SSO solution developed by Yale University
      You can find the project page here : http://www.yale.edu/tp/auth
    * Cocoon :
      XML framework distributed by the Apache foundation under Apache license;
      Please find the full text here : http://cocoon.apache.org/2.1/license.html
    * Mod_dav:
      A DAV module for Apache web server
      You can find the project page here : http://www.webdav.org/mod_dav
    * IMP :
      webmail from Horde application framework
      You can find the project page here : http://www.horde.org
    * . To be completed
*/

package org.esupportail.portal.channels.CStockage.exception;

/**
 * Id: DataBaseException.java,v 1.0 13 janvier 2005<br/>
 * Copyright (c) 2005 Esup Portail (www.esup-portail.org)<br/>
 * Classes: DataBaseException<br/>
 * Original Author: Yohan Colmant<br/>
 * Called when there is an error in the database access<br/>
 */
public class DataBaseException extends ChannelException {
	
	static final long serialVersionUID = 797971049;
	
	
	/**
	 * Constructor
	 */
	public DataBaseException() {
		super(1049);		
	}
	
	
}
